Module databases

Module databases 

Database-specific modules for the sync example.

Modules

any
Any database types and helpers for the sync example.
current
Current database types and helpers for the sync example.
immutable
Immutable database types and helpers for the sync example.
immutable_compact
Compact immutable database types and helpers for compact sync demonstration.
keyless
Keyless database types and helpers for the sync example.
keyless_compact
Compact keyless database types and helpers for compact sync demonstration.

Enums

DatabaseType
Database family to synchronize.
StorageKind
Backing storage kind used by a compact-mode server.
SyncMode
Synchronization mode to use.

Traits

CompactSyncable
Capability trait for databases that can serve compact sync targets.
ExampleDatabase
Common surface shared by all database adapters used by the sync example binaries.
Syncable
Capability trait for databases that support full replay-based sync.