Current database types and helpers for the sync example.
A current database extends an any database with an activity bitmap that tracks which
operations are active (i.e. represent the current state of their key) vs inactive (superseded or
deleted). Its canonical root folds the ops root, a grafted merkle root (combining bitmap chunks
with ops subtree roots), and an optional partial-chunk digest. See current module
documentation for more details.
For sync, the engine targets the ops root (not the canonical root). The operations and proof
format are identical to any – the bitmap is reconstructed deterministically from the
operations after sync completes. See the Root structure
module documentation for details.
This module re-uses the same Operation type as super::any since the underlying
operations log is the same.
Functions
- create_
config - Create a database configuration.