pub type Database<E> = Db<Family, E, Key, Value, Hasher, Translator, CHUNK_SIZE, Sequential>;Expand description
Database type alias.
Aliased Type
pub struct Database<E> { /* private fields */ }Trait Implementations
Sourceimpl<E> ExampleDatabase for Database<E>
impl<E> ExampleDatabase for Database<E>
Sourcetype Operation = Operation<Family, Update<Digest, FixedEncoding<Digest>>>
type Operation = Operation<Family, Update<Digest, FixedEncoding<Digest>>>
The type of operations in the database.
Sourcefn create_test_operations(
count: usize,
seed: u64,
_starting_loc: u64,
) -> Vec<Self::Operation>
fn create_test_operations( count: usize, seed: u64, _starting_loc: u64, ) -> Vec<Self::Operation>
Create test operations with the given count and seed. Read more
Sourceasync fn add_operations(
&mut self,
operations: Vec<Self::Operation>,
) -> Result<(), Error<Family>>
async fn add_operations( &mut self, operations: Vec<Self::Operation>, ) -> Result<(), Error<Family>>
Add operations to the database, ignoring any input that doesn’t end with a commit
operation.
Sourcefn current_floor(&self) -> u64
fn current_floor(&self) -> u64
Return the floor anchor a caller should pass as
starting_loc when generating a stream
to append to this db’s current state.Sourceimpl<E> Syncable for Database<E>
impl<E> Syncable for Database<E>
Sourceasync fn size(&self) -> Location
async fn size(&self) -> Location
Get the total number of operations in the database (including pruned operations).
Sourceasync fn sync_boundary(&self) -> Location
async fn sync_boundary(&self) -> Location
Get the most recent location from which this database can safely be synced. Read more