pub type Operation = Operation<Family, Key, Value>;
Operation type alias.
pub enum Operation { Set(Digest, Digest), Commit(Option<Digest>, Location<Family>), }
Set a key to a value. The key must not already exist.
Commit with optional metadata and the inactivity floor location. Operations before the floor are declared inactive by the application.