Module immutable_compact

Module immutable_compact 

Compact immutable database types and helpers for compact sync demonstration.

Functions

create_config
Create a database configuration for the compact immutable variant.

Type Aliases

Database
Database type alias.
Operation
Operation type alias.