Operation

Type Alias Operation 

pub type Operation = Operation<Family, Key, Value>;
Operation type alias.

Aliased Type

pub enum Operation {
    Set(Digest, Digest),
    Commit(Option<Digest>, Location<Family>),
}

Variants



Set(Digest, Digest)

Set a key to a value. The key must not already exist.



Commit(Option<Digest>, Location<Family>)

Commit with optional metadata and the inactivity floor location. Operations before the floor are declared inactive by the application.