Type Alias Operation
Source pub type Operation = Operation<Family, Value>;
pub enum Operation {
Append(Digest),
Commit(Option<Digest>, Location<Family>),
}
Wraps the value appended to the database by this operation.
Indicates the database has been committed, carrying optional metadata and the inactivity
floor location declared by the application at commit time.