pub fn create_config(_context: &impl BufferPooler) -> CompactConfig<Sequential>Expand description
Create a database configuration for the compact keyless variant.
pub fn create_config(_context: &impl BufferPooler) -> CompactConfig<Sequential>Create a database configuration for the compact keyless variant.