Operation

Type Alias Operation 

pub type Operation = Operation<Family, Value>;
Operation type alias.

Aliased Type

pub enum Operation {
    Append(Digest),
    Commit(Option<Digest>, Location<Family>),
}

Variants



Append(Digest)

Wraps the value appended to the database by this operation.



Commit(Option<Digest>, Location<Family>)

Indicates the database has been committed, carrying optional metadata and the inactivity floor location declared by the application at commit time.