Database-specific modules for the sync example.
Modules
- any
- Any database types and helpers for the sync example.
- current
- Current database types and helpers for the sync example.
- immutable
- Immutable database types and helpers for the sync example.
- immutable_
compact - Compact immutable database types and helpers for compact sync demonstration.
- keyless
- Keyless database types and helpers for the sync example.
- keyless_
compact - Compact keyless database types and helpers for compact sync demonstration.
Enums
- Database
Type - Database family to synchronize.
- Storage
Kind - Backing storage kind used by a compact-mode server.
- Sync
Mode - Synchronization mode to use.
Traits
- Compact
Syncable - Capability trait for databases that can serve compact sync targets.
- Example
Database - Common surface shared by all database adapters used by the sync example binaries.
- Syncable
- Capability trait for databases that support full replay-based sync.